@@ -32,7 +32,7 @@ pub struct BackendArg {
 impl<A: AsRef<str>> From<A> for BackendArg {
     fn from(s: A) -> Self {
         let s = s.as_ref();
-        if let Some(fa) = REGISTRY_BACKEND_MAP.get(s) {
+        if let Some(fa) = REGISTRY_BACKEND_MAP.get(s).and_then(|rbm| rbm.first()) {
             fa.clone()
         } else {
             Self::new(s, s)
@@ -49,6 +49,7 @@ impl From<BackendMeta> for BackendArg {
 impl BackendArg {
     pub fn new(short: &str, full: &str) -> Self {
         let short = unalias_backend(short).to_string();
+        let short = regex!(r#"\[.+\]$"#).replace_all(&short, "").to_string();
 
         let (backend, mut name) = full.split_once(':').unwrap_or(("", full));
 
