@@ -4,6 +4,7 @@ use std::path::Path;
 use crate::env;
 
 mod bash;
+mod elvish;
 mod fish;
 mod nushell;
 mod xonsh;
@@ -12,6 +13,7 @@ mod zsh;
 #[derive(Debug, Clone, Copy, PartialEq, Eq, clap::ValueEnum)]
 pub enum ShellType {
     Bash,
+    Elvish,
     Fish,
     Nu,
     Xonsh,
@@ -23,6 +25,8 @@ impl ShellType {
         let shell = env::var("MISE_SHELL").or(env::var("SHELL")).ok()?;
         if shell.ends_with("bash") {
             Some(ShellType::Bash)
+        } else if shell.ends_with("elvish") {
+            Some(ShellType::Elvish)
         } else if shell.ends_with("fish") {
             Some(ShellType::Fish)
         } else if shell.ends_with("nu") {
@@ -41,6 +45,7 @@ impl Display for ShellType {
     fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         match self {
             Self::Bash => write!(f, "bash"),
+            Self::Elvish => write!(f, "elvish"),
             Self::Fish => write!(f, "fish"),
             Self::Nu => write!(f, "nu"),
             Self::Xonsh => write!(f, "xonsh"),
@@ -60,6 +65,7 @@ pub trait Shell {
 pub fn get_shell(shell: Option<ShellType>) -> Option<Box<dyn Shell>> {
     match shell.or_else(ShellType::load) {
         Some(ShellType::Bash) => Some(Box::<bash::Bash>::default()),
+        Some(ShellType::Elvish) => Some(Box::<elvish::Elvish>::default()),
         Some(ShellType::Fish) => Some(Box::<fish::Fish>::default()),
         Some(ShellType::Nu) => Some(Box::<nushell::Nushell>::default()),
         Some(ShellType::Xonsh) => Some(Box::<xonsh::Xonsh>::default()),
