@@ -29,7 +29,6 @@ pub fn handle_shim() -> Result<()> {
     let args = env::ARGS.read().unwrap();
     trace!("shim[{bin_name}] args: {}", args.join(" "));
     let mut args: Vec<OsString> = args.iter().map(OsString::from).collect();
-    remove_shim_dir_from_path();
     args[0] = which_shim(&env::MISE_BIN_NAME)?.into();
     env::set_var("__MISE_SHIM", "1");
     let exec = Exec {
@@ -272,22 +271,6 @@ fn make_shim(target: &Path, shim: &Path) -> Result<()> {
     Ok(())
 }
 
-/// prevent shims from being called in a loop
-fn remove_shim_dir_from_path() {
-    let path = env::var_os(&*env::PATH_KEY).unwrap_or_default();
-    let paths = env::split_paths(&path).filter(|p| {
-        p != *dirs::SHIMS
-            && !p
-                .canonicalize()
-                .is_ok_and(|p| p == dirs::SHIMS.canonicalize().unwrap_or_default())
-    });
-    let path = env::join_paths(paths)
-        .unwrap()
-        .to_string_lossy()
-        .to_string();
-    env::set_var(&*env::PATH_KEY, &path);
-}
-
 fn err_no_version_set(ts: Toolset, bin_name: &str, tvs: Vec<ToolVersion>) -> Result<PathBuf> {
     if tvs.is_empty() {
         bail!("{} is not a valid shim", bin_name);
